summaryrefslogtreecommitdiffstats
path: root/cc/resources/raster_worker_pool.h
diff options
context:
space:
mode:
authortomhudson@google.com <tomhudson@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-18 15:01:50 +0000
committertomhudson@google.com <tomhudson@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2013-09-18 15:01:50 +0000
commitb992782c3d48258799d34fdd48f931078e39f979 (patch)
tree45718bf908d2230d15b59f2c77d506b2f14ee0df /cc/resources/raster_worker_pool.h
parent9976c1d42b52e4228cf998afb03267f2d3b3ce40 (diff)
downloadchromium_src-b992782c3d48258799d34fdd48f931078e39f979.zip
chromium_src-b992782c3d48258799d34fdd48f931078e39f979.tar.gz
chromium_src-b992782c3d48258799d34fdd48f931078e39f979.tar.bz2
Revert "Adding support for RGBA_4444 tile textures"
This reverts commit 8e6d15826280b9f11a28060b5b2d2bbef17d15bc (r223830; http://crrev.com/21159007). Although the 4444 textures work on S4, they break on N7v2 and N10. (We've got inconsistent reports about N4.) Passing --disable-4444-textures isn't sufficient to fix the problems. ilevy@ points out that the commit bot is using GN, so could easily have missed this breakage. We're hoping to switch to N4, but in this case there's no guarantee that that would have caught it either. Perhaps the main patch can be landed in pieces next time? From N7: E/chromium(32513): [ERROR:gles2_cmd_decoder.cc(5770)] [.RenderCompositor-0x783c9880]RENDER WARNING: texture bound to texture unit 0 is not renderable. It maybe non-power-of-2 and have incompatible texture filtering or is not 'texture complete' From N10: I/chromium( 2104): [INFO:CONSOLE(0)] "[.WebGLRenderingContext]RENDER WARNING: texture bound to texture unit 0 is not renderable. It maybe non-power-of-2 and have incompatible texture filtering or is not 'texture complete'", source: file:///sdcard/clanktemp/index.html (0) R=skyostil@chromium.org TBR=kaanb@chromium.org BUG=245774,272539 Review URL: https://codereview.chromium.org/24219002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@223871 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/resources/raster_worker_pool.h')
-rw-r--r--cc/resources/raster_worker_pool.h17
1 files changed, 8 insertions, 9 deletions
diff --git a/cc/resources/raster_worker_pool.h b/cc/resources/raster_worker_pool.h
index b12a1b4..a53e52f 100644
--- a/cc/resources/raster_worker_pool.h
+++ b/cc/resources/raster_worker_pool.h
@@ -11,11 +11,11 @@
#include "cc/debug/rendering_stats_instrumentation.h"
#include "cc/resources/picture_pile_impl.h"
#include "cc/resources/raster_mode.h"
-#include "cc/resources/resource.h"
-#include "cc/resources/resource_provider.h"
#include "cc/resources/tile_priority.h"
#include "cc/resources/worker_pool.h"
#include "third_party/khronos/GLES2/gl2.h"
+// TODO(robertphillips): change this to "class SkBaseDevice;"
+#include "third_party/skia/include/core/SkDevice.h"
namespace skia {
class LazyPixelRef;
@@ -24,6 +24,7 @@ class LazyPixelRef;
namespace cc {
class PicturePileImpl;
class PixelBufferRasterWorkerPool;
+class Resource;
class ResourceProvider;
namespace internal {
@@ -33,13 +34,11 @@ class CC_EXPORT RasterWorkerPoolTask
public:
typedef std::vector<scoped_refptr<WorkerPoolTask> > TaskVector;
// Returns true if |buffer| was written to. False indicate that
// the content of |buffer| is undefined and the resource doesn't
// need to be initialized.
- virtual bool RunOnWorkerThread(unsigned thread_index,
- void* buffer,
- gfx::Size size,
- int stride) = 0;
+ virtual bool RunOnWorkerThread(SkBaseDevice* device,
+ unsigned thread_index) = 0;
virtual void CompleteOnOriginThread() = 0;
void DidRun(bool was_canceled);
@@ -187,7 +186,7 @@ class CC_EXPORT RasterWorkerPool : public WorkerPool {
virtual void ScheduleTasks(RasterTask::Queue* queue) = 0;
// Returns the format that needs to be used for raster task resources.
- virtual ResourceFormat GetResourceFormat() const = 0;
+ virtual GLenum GetResourceFormat() const = 0;
// TODO(vmpstr): Figure out an elegant way to not pass this many parameters.
static RasterTask CreateRasterTask(
@@ -33,13 +34,11 @@ class CC_EXPORT RasterWorkerPoolTask
public:
typedef std::vector<scoped_refptr<WorkerPoolTask> > TaskVector;
- // Returns true if |buffer| was written to. False indicate that
- // the content of |buffer| is undefined and the resource doesn't
+ // Returns true if |device| was written to. False indicate that
+ // the content of |device| is undefined and the resource doesn't
// need to be initialized.